@@ -1,5 +1,5 @@
 package App::SmokeBrew::Plugin::CPANPLUS::YACSmoke;
-$App::SmokeBrew::Plugin::CPANPLUS::YACSmoke::VERSION = '0.48';
+$App::SmokeBrew::Plugin::CPANPLUS::YACSmoke::VERSION = '0.50';
 #ABSTRACT: A smokebrew plugin for CPANPLUS::YACSmoke based smokers
 
 use strict;
@@ -27,7 +27,7 @@ has '_cpanplus' => (
 sub _build__cpanplus {
   my $self = shift;
   $self->builddir->mkpath;
-  my $default = 'B/BI/BINGOS/CPANPLUS-0.9142.tar.gz';
+  my $default = 'B/BI/BINGOS/CPANPLUS-0.9168.tar.gz';
   my $path;
   my $ff = File::Fetch->new( uri => 'http://cpanidx.org/cpanidx/yaml/mod/CPANPLUS' );
   my $stat = $ff->fetch( to => $self->builddir->absolute );
@@ -142,7 +142,7 @@ BEGIN {
 
     $ENV{'PERL5LIB'} = join $Config{'path_sep'}, grep { defined }
                         $PRIV_LIB,              # to find the boxed config
-                        #$LIB_DIR,               # the CPANPLUS libs
+                        $LIB_DIR,               # the CPANPLUS libs
                         $ENV{'PERL5LIB'};       # original PERL5LIB
 
 }
@@ -318,7 +318,7 @@ App::SmokeBrew::Plugin::CPANPLUS::YACSmoke - A smokebrew plugin for CPANPLUS::YA
 
 =head1 VERSION
 
-version 0.48
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -358,7 +358,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Chris Williams.
+This software is copyright (c) 2017 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
